#!/usr/bin/env python
# All other single corpus
# Author: Thamme Gowda [tg (at) isi (dot) edu] 
# Created: 5/23/20

from mtdata.index import Index, Entry


def load_all(index: Index):

    # === IITB hin eng http://www.cfilt.iitb.ac.in/iitb_parallel/
    cite="""@article{DBLP:journals/corr/abs-1710-02855,
  author    = {Anoop Kunchukuttan and
               Pratik Mehta and
               Pushpak Bhattacharyya},
  title     = {The {IIT} Bombay English-Hindi Parallel Corpus},
  journal   = {CoRR},
  volume    = {abs/1710.02855},
  year      = {2017},
  url       = {http://arxiv.org/abs/1710.02855},
  archivePrefix = {arXiv},
  eprint    = {1710.02855},
  timestamp = {Mon, 13 Aug 2018 16:48:50 +0200},
  biburl    = {https://dblp.org/rec/journals/corr/abs-1710-02855.bib},
  bibsource = {dblp computer science bibliography, https://dblp.org}
}"""
    l1, l2 = 'hi', 'en'
    for version, prefix in [
        #('v1_0', 'http://www.cfilt.iitb.ac.in/iitb_parallel/iitb_corpus_download'),
        ('v1_5', 'http://www.cfilt.iitb.ac.in/~moses/iitb_en_hi_parallel/iitb_corpus_download')]:
        # they also have v2, but the link is broken http://www.cfilt.iitb.ac.in/iitb_parallel/
        # version is not explicit, but guessed from file modification time and description
        url = prefix + "/parallel.tgz"
        ent = Entry(langs=(l1, l2), url=url, filename=f'IITB{version}-hin_eng-parallel.tar.gz',
                    name=f'IITB{version}_train', in_ext='txt', cite=cite,
                    in_paths=[f'parallel/IITB.en-hi.{l1}',
                              f'parallel/IITB.en-hi.{l2}'])
        index.add_entry(ent)

        url = prefix + "/dev_test.tgz"
        for split in ['dev', 'test']:
            f1 = f'dev_test/{split}.{l1}'
            f2 = f'dev_test/{split}.{l2}'
            ent = Entry(langs=(l1, l2), url=url, filename=f'IITB{version}-hin_eng-dev_test.tar.gz',
                        name=f'IITB{version}_{split}', in_ext='txt',
                        in_paths=[f1, f2], cite=cite)
            index.add_entry(ent)


    # == Japanese ==
    cite="""@misc{neubig11kftt,
    author = {Graham Neubig},
    title = {The {Kyoto} Free Translation Task},
    howpublished = {http://www.phontron.com/kftt},
    year = {2011}
    }"""
    url = "http://www.phontron.com/kftt/download/kftt-data-1.0.tar.gz"
    l1, l2 = 'en', 'ja'
    for split in ['train', 'test', 'dev', 'tune']:
        f1 = f'kftt-data-1.0/data/orig/kyoto-{split}.{l1}'
        f2 = f'kftt-data-1.0/data/orig/kyoto-{split}.{l2}'
        ent = Entry(langs=(l1, l2), url=url, filename="kftt-data-1.0.tar.gz",
                    name=f'kftt_v1_{split}', in_ext='txt',
                    in_paths=[f1, f2], cite=cite)
        index.add_entry(ent)


#!/usr/bin/env python
#
# Author: Thamme Gowda [tg (at) isi (dot) edu] 
# Created: 6/9/20
from mtdata.index import Entry, Index

def load_all(index: Index):
    data="""an-ca an-de an-en an-es an-fr an-gl an-it an-pl an-pt an-ru ar-arz ar-az ar-ba ar-be ar-bg ar-bn ar-br ar-bs ar-ca ar-ceb
 ar-cs ar-da ar-de ar-el ar-en ar-eo ar-es ar-et ar-eu ar-fa ar-fi ar-fr ar-gl ar-he ar-hi ar-hr ar-hu ar-id ar-is ar-it
 ar-ja ar-kk ar-ko ar-lt ar-mk ar-ml ar-mr ar-nds ar-ne ar-nl ar-no ar-pl ar-pt ar-ro ar-ru ar-sh ar-si ar-sk ar-sl ar-sq
 ar-sr ar-sv ar-sw ar-ta ar-te ar-tl ar-tr ar-tt ar-uk ar-vi arz-de arz-en arz-es arz-fr ar-zh arz-it arz-pt arz-ru as-de as-es
 as-fr as-it azb-fr az-bg az-ca az-cs az-da az-de az-el az-en az-es az-et az-fa az-fi az-fr az-gl az-he az-hr az-hu az-id
 az-it az-ja az-ko az-nl az-no az-pl az-pt az-ro az-ru az-sr az-sv az-ta az-tr az-uk az-vi az-zh ba-bg ba-ca ba-cs ba-da
 ba-de ba-el ba-en ba-es ba-fi ba-fr ba-gl ba-hr ba-hu ba-id ba-it ba-ja ba-nl ba-no ba-pl ba-pt bar-de bar-en bar-es bar-fr
 bar-it ba-ro bar-pt bar-ru ba-ru ba-sh ba-sk ba-sl ba-sr ba-sv ba-tr ba-uk ba-zh be-bg be-ca be-cs be-de be-en be-es be-fi
 be-fr be-he be-hu be-it be-ja be-nl be-no be-pl be-pt be-ro be-ru be-sr be-sv be-uk bg-bn bg-bs bg-ca bg-ceb bg-cs bg-da
 bg-de bg-el bg-en bg-eo bg-es bg-et bg-eu bg-fa bg-fi bg-fr bg-gl bg-he bg-hi bg-hr bg-hu bg-id bg-is bg-it bg-ja bg-kk
 bg-ko bg-lt bg-mk bg-ml bg-mr bg-nds bg-ne bg-nl bg-no bg-pl bg-pt bg-ro bg-ru bg-sh bg-si bg-sk bg-sl bg-sq bg-sr bg-sv
 bg-sw bg-ta bg-te bg-tl bg-tr bg-tt bg-uk bg-vi bg-zh bn-bs bn-ca bn-cs bn-da bn-de bn-el bn-en bn-eo bn-es bn-et bn-eu
 bn-fa bn-fi bn-fr bn-gl bn-he bn-hi bn-hr bn-hu bn-id bn-it bn-ja bn-ko bn-lt bn-mk bn-nl bn-no bn-pl bn-pt bn-ro bn-ru
 bn-sh bn-sk bn-sl bn-sq bn-sr bn-sv bn-ta bn-tr bn-uk bn-vi bn-zh br-de br-en br-es br-fr br-it br-pt br-ru br-uk bs-ca
 bs-cs bs-da bs-de bs-el bs-en bs-eo bs-es bs-et bs-eu bs-fa bs-fi bs-fr bs-gl bs-he bs-hi bs-hr bs-hu bs-id bs-is bs-it
 bs-ja bs-ko bs-lt bs-mk bs-ml bs-mr bs-nl bs-no bs-pl bs-pt bs-ro bs-ru bs-sh bs-si bs-sk bs-sl bs-sq bs-sr bs-sv bs-ta
 bs-te bs-tl bs-tr bs-uk bs-vi bs-zh ca-ceb ca-cs ca-da ca-de ca-el ca-en ca-eo ca-es ca-et ca-eu ca-fa ca-fi ca-fo ca-fr
 ca-fy ca-gl ca-he ca-hi ca-hr ca-hu ca-id ca-is ca-it ca-ja ca-ka ca-kk ca-ko ca-la ca-lb ca-lt ca-mk ca-ml ca-mr ca-nds
 ca-ne ca-nl ca-no ca-oc ca-pl ca-pt ca-ro ca-ru ca-sh ca-si ca-sk ca-sl ca-sq ca-sr ca-sv ca-sw ca-ta ca-te ca-tl ca-tr
 ca-tt ca-uk ca-vi ca-zh ceb-cs ceb-de ceb-en ceb-es ceb-fi ceb-fr ceb-hu ceb-it ceb-ja ceb-nl ceb-no ceb-pl ceb-pt ceb-ro ceb-ru ceb-sv
 ceb-uk cs-da cs-de cs-el cs-en cs-eo cs-es cs-et cs-eu cs-fa cs-fi cs-fr cs-fy cs-gl cs-he cs-hi cs-hr cs-hu cs-id cs-is
 cs-it cs-ja cs-ka cs-kk cs-ko cs-la cs-lt cs-mk cs-ml cs-mr cs-nds cs-ne cs-nl cs-no cs-oc cs-pl cs-pt cs-ro cs-ru cs-sh
 cs-si cs-sk cs-sl cs-sq cs-sr cs-sv cs-sw cs-ta cs-te cs-tl cs-tr cs-tt cs-uk cs-vi cs-zh da-de da-el da-en da-eo da-es
 da-et da-eu da-fa da-fi da-fo da-fr da-gl da-he da-hi da-hr da-hu da-id da-is da-it da-ja da-ko da-lt da-mk da-ml da-mr
 da-nds da-ne da-nl da-no da-pl da-pt da-ro da-ru da-sh da-si da-sk da-sl da-sq da-sr da-sv da-sw da-ta da-te da-tl da-tr
 da-tt da-uk da-vi da-zh de-el de-en de-eo de-es de-et de-eu de-fa de-fi de-fo de-fr de-fy de-gl de-gom de-he de-hi de-hr
 de-hu de-hy de-id de-is de-it de-ja de-ka de-kk de-ko de-la de-lb de-lt de-mk de-ml de-mr de-nds de-ne de-nl de-no de-oc
 de-pl de-pt de-rm de-ro de-ru de-sh de-si de-sk de-sl de-sq de-sr de-sv de-sw de-ta de-te de-tg de-tl de-tr de-tt de-uk
 de-vi de-wuu de-zh el-en el-eo el-es el-et el-eu el-fa el-fi el-fr el-gl el-he el-hi el-hr el-hu el-id el-is el-it el-ja
 el-ko el-lt el-mk el-ml el-mr el-nl el-no el-pl el-pt el-ro el-ru el-sh el-si el-sk el-sl el-sq el-sr el-sv el-sw el-ta
 el-te el-tl el-tr el-uk el-vi el-zh en-eo en-es en-et en-eu en-fa en-fi en-fo en-fr en-fy en-gl en-he en-hi en-hr en-hu
 en-id en-io en-is en-it en-ja en-jv en-ka en-kk en-ko en-la en-lb en-lmo en-lt en-mg en-mk en-ml en-mr en-mwl en-nds_nl en-nds
 en-ne en-nl en-no en-oc en-pl en-pt en-ro en-ru en-sh en-simple en-si en-sk en-sl en-sq en-sr en-sv en-sw en-ta en-te en-tg
 en-tl en-tr en-tt en-ug en-uk en-vi en-wuu en-zh eo-es eo-et eo-eu eo-fa eo-fi eo-fr eo-gl eo-he eo-hi eo-hr eo-hu eo-id
 eo-is eo-it eo-ja eo-ko eo-lt eo-mk eo-ml eo-mr eo-nds eo-nl eo-no eo-pl eo-pt eo-ro eo-ru eo-sh eo-si eo-sk eo-sl eo-sq
 eo-sr eo-sv eo-ta eo-te eo-tl eo-tr eo-uk eo-vi eo-zh es-et es-eu es-fa es-fi es-fo es-fr es-fy es-gl es-gom es-he es-hi
 es-hr es-hu es-hy es-id es-is es-it es-ja es-jv es-ka es-kk es-ko es-la es-lb es-lt es-mk es-ml es-mr es-nds es-ne es-nl
 es-no es-oc es-pl es-pt es-ro es-ru es-sh es-si es-sk es-sl es-sq es-sr es-sv es-sw es-ta es-te es-tl es-tr es-tt es-uk
 es-vi es-wuu es-zh et-eu et-fa et-fi et-fr et-gl et-he et-hi et-hr et-hu et-id et-is et-it et-ja et-ko et-lt et-mk et-ml
 et-mr et-nl et-no et-pl et-pt et-ro et-ru et-sh et-si et-sk et-sl et-sq et-sr et-sv et-ta et-te et-tl et-tr et-uk et-vi
 et-zh eu-fa eu-fi eu-fr eu-gl eu-he eu-hi eu-hr eu-hu eu-id eu-is eu-it eu-ja eu-ko eu-lt eu-mk eu-ml eu-mr eu-nl eu-no
 eu-pl eu-pt eu-ro eu-ru eu-sh eu-sk eu-sl eu-sq eu-sr eu-sv eu-ta eu-te eu-tr eu-uk eu-vi eu-zh fa-fi fa-fr fa-gl fa-he
 fa-hi fa-hr fa-hu fa-id fa-it fa-ja fa-ko fa-lt fa-mk fa-ml fa-mr fa-nl fa-no fa-pl fa-pt fa-ro fa-ru fa-sh fa-sk fa-sl
 fa-sq fa-sr fa-sv fa-ta fa-te fa-tr fa-uk fa-vi fa-zh fi-fr fi-gl fi-he fi-hi fi-hr fi-hu fi-id fi-is fi-it fi-ja fi-ko
 fi-lt fi-mk fi-ml fi-mr fi-nds fi-ne fi-nl fi-no fi-oc fi-pl fi-pt fi-ro fi-ru fi-sh fi-si fi-sk fi-sl fi-sq fi-sr fi-sv
 fi-sw fi-ta fi-te fi-tl fi-tr fi-tt fi-uk fi-vi fi-zh fo-fr fo-it fo-nl fo-pl fo-pt fo-ru fo-sv fr-fy fr-gl fr-gom fr-he
 fr-hi fr-hr fr-hu fr-hy fr-id fr-is fr-it fr-ja fr-jv fr-ka fr-kk fr-ko fr-la fr-lb fr-lt fr-mg fr-mk fr-ml fr-mr fr-nds
 fr-ne fr-nl fr-no fr-oc fr-pl fr-pt fr-ro fr-ru fr-sh fr-si fr-sk fr-sl fr-sq fr-sr fr-sv fr-sw fr-ta fr-te fr-tl fr-tr
 fr-tt fr-uk fr-vi fr-wuu fr-zh fy-it fy-nl fy-pl fy-pt fy-ru fy-sv gl-he gl-hi gl-hr gl-hu gl-id gl-is gl-it gl-ja gl-ko
 gl-lt gl-mk gl-ml gl-mr gl-nds gl-ne gl-nl gl-no gl-oc gl-pl gl-pt gl-ro gl-ru gl-sh gl-si gl-sk gl-sl gl-sq gl-sr gl-sv
 gl-ta gl-te gl-tl gl-tr gl-tt gl-uk gl-vi gl-zh gom-it gom-pt gom-ru he-hi he-hr he-hu he-id he-is he-it he-ja he-ko he-lt
 he-mk he-ml he-mr he-nl he-no he-pl he-pt he-ro he-ru he-sh he-si he-sk he-sl he-sq he-sr he-sv he-sw he-ta he-te he-tl
 he-tr he-uk he-vi he-zh hi-hr hi-hu hi-id hi-it hi-ja hi-ko hi-lt hi-mk hi-mr hi-ne hi-nl hi-no hi-pl hi-pt hi-ro hi-ru
 hi-sh hi-sk hi-sl hi-sq hi-sr hi-sv hi-ta hi-te hi-tr hi-uk hi-vi hi-zh hr-hu hr-id hr-is hr-it hr-ja hr-ko hr-lt hr-mk
 hr-ml hr-mr hr-ne hr-nl hr-no hr-pl hr-pt hr-ro hr-ru hr-sh hr-si hr-sk hr-sl hr-sq hr-sr hr-sv hr-ta hr-te hr-tl hr-tr
 hr-uk hr-vi hr-zh hu-id hu-is hu-it hu-ja hu-kk hu-ko hu-lt hu-mk hu-ml hu-mr hu-nds hu-ne hu-nl hu-no hu-oc hu-pl hu-pt
 hu-ro hu-ru hu-sh hu-si hu-sk hu-sl hu-sq hu-sr hu-sv hu-sw hu-ta hu-te hu-tl hu-tr hu-uk hu-vi hu-zh hy-it hy-pt hy-ru
 id-is id-it id-ja id-jv id-ko id-lt id-mk id-ml id-mr id-ne id-nl id-no id-pl id-pt id-ro id-ru id-sh id-si id-sk id-sl
 id-sq id-sr id-sv id-sw id-ta id-te id-tl id-tr id-tt id-uk id-vi id-zh is-it is-ja is-lt is-mk is-nl is-no is-pl is-pt
 is-ro is-ru is-sh is-sk is-sl is-sr is-sv is-tr is-uk is-vi is-zh it-ja it-jv it-ka it-kk it-ko it-la it-lb it-lmo it-lt
 it-mk it-ml it-mr it-nds it-ne it-nl it-no it-oc it-pl it-pt it-ro it-ru it-scn it-sh it-si it-sk it-sl it-sq it-sr it-sv
 it-sw it-ta it-te it-tl it-tr it-tt it-uk it-vi it-wuu it-zh ja-kk ja-ko ja-lt ja-mk ja-ml ja-mr ja-nds ja-nl ja-no ja-pl
 ja-pt ja-ro ja-ru ja-sh ja-si ja-sk ja-sl ja-sq ja-sr ja-sv ja-sw ja-ta ja-te ja-tl ja-tr ja-tt ja-uk ja-vi ja-zh jv-pt
 ka-nl ka-pl ka-pt ka-ru ka-sv kk-nl kk-no kk-pl kk-pt kk-ro kk-ru kk-sv kk-tr kk-uk ko-lt ko-mk ko-ml ko-mr ko-nl ko-no
 ko-pl ko-pt ko-ro ko-ru ko-sh ko-sk ko-sl ko-sq ko-sr ko-sv ko-ta ko-te ko-tr ko-uk ko-vi ko-zh la-nl la-pl la-pt la-ro
 la-ru la-sv lb-nl lb-pl lb-pt lb-ru lb-sv lt-mk lt-ml lt-mr lt-nl lt-no lt-pl lt-pt lt-ro lt-ru lt-sh lt-si lt-sk lt-sl
 lt-sq lt-sr lt-sv lt-ta lt-te lt-tl lt-tr lt-uk lt-vi lt-zh mk-ml mk-mr mk-nl mk-no mk-pl mk-pt mk-ro mk-ru mk-sh mk-si
 mk-sk mk-sl mk-sq mk-sr mk-sv mk-ta mk-te mk-tl mk-tr mk-uk mk-vi mk-zh ml-nl ml-no ml-pl ml-pt ml-ro ml-ru ml-sh ml-sk
 ml-sl ml-sq ml-sr ml-sv ml-tr ml-uk ml-vi ml-zh mr-nl mr-no mr-pl mr-pt mr-ro mr-ru mr-sh mr-sk mr-sl mr-sq mr-sr mr-sv
 mr-tr mr-uk mr-vi mr-zh mwl-pt nds_nl-nl nds-nl nds-no nds-pl nds-pt nds-ro nds-ru nds-sv nds-uk ne-nl ne-no ne-pl ne-pt ne-ro ne-ru
 ne-sh ne-sk ne-sl ne-sv ne-uk nl-no nl-oc nl-pl nl-pt nl-ro nl-ru nl-sh nl-si nl-sk nl-sl nl-sq nl-sr nl-sv nl-sw nl-ta
 nl-te nl-tl nl-tr nl-tt nl-uk nl-vi nl-zh no-pl no-pt no-ro no-ru no-sh no-si no-sk no-sl no-sq no-sr no-sv no-sw no-ta
 no-te no-tl no-tr no-tt no-uk no-vi no-zh oc-pl oc-pt oc-ro oc-ru oc-sv pl-pt pl-ro pl-ru pl-sh pl-si pl-sk pl-sl pl-sq
 pl-sr pl-sv pl-sw pl-ta pl-te pl-tl pl-tr pl-tt pl-uk pl-vi pl-zh pt-ro pt-ru pt-sh pt-si pt-sk pt-sl pt-sq pt-sr pt-sv
 pt-sw pt-ta pt-te pt-tl pt-tr pt-tt pt-uk pt-vi pt-wuu pt-zh ro-ru ro-sh ro-si ro-sk ro-sl ro-sq ro-sr ro-sv ro-sw ro-ta
 ro-te ro-tl ro-tr ro-tt ro-uk ro-vi ro-zh ru-sh ru-si ru-sk ru-sl ru-sq ru-sr ru-sv ru-sw ru-ta ru-te ru-tg ru-tl ru-tr
 ru-tt ru-uk ru-vi ru-wuu ru-zh sh-si sh-sk sh-sl sh-sq sh-sr sh-sv sh-ta sh-te sh-tl sh-tr sh-uk sh-vi sh-zh si-sk si-sl
 si-sq si-sr si-sv si-tr si-uk si-vi si-zh sk-sl sk-sq sk-sr sk-sv sk-ta sk-te sk-tl sk-tr sk-uk sk-vi sk-zh sl-sq sl-sr
 sl-sv sl-ta sl-te sl-tl sl-tr sl-uk sl-vi sl-zh sq-sr sq-sv sq-ta sq-te sq-tl sq-tr sq-uk sq-vi sq-zh sr-sv sr-ta sr-te
 sr-tl sr-tr sr-uk sr-vi sr-zh sv-sw sv-ta sv-te sv-tl sv-tr sv-tt sv-uk sv-vi sv-zh sw-tr sw-uk sw-vi sw-zh ta-tr ta-uk
 ta-vi ta-zh te-tr te-uk te-vi te-zh tl-tr tl-uk tl-vi tl-zh tr-tt tr-uk tr-vi tr-zh tt-uk tt-zh uk-vi uk-zh vi-zh wuu-zh"""
    cite = """@article{wikimatrix1,
    author    = {Holger Schwenk and Vishrav Chaudhary and Shuo Sun and Hongyu Gong and Francisco Guzm{\'{a}}n},
    title     = {WikiMatrix: Mining 135M Parallel Sentences in 1620 Language Pairs from Wikipedia},
    journal   = {CoRR},
    volume    = {abs/1907.05791},
    year      = {2019},
    url       = {http://arxiv.org/abs/1907.05791},
    archivePrefix = {arXiv},
    eprint    = {1907.05791},
    timestamp = {Wed, 17 Jul 2019 10:27:36 +0200},
    biburl    = {https://dblp.org/rec/journals/corr/abs-1907-05791.bib},
    bibsource = {dblp computer science bibliography, https://dblp.org}}"""
    url_pat = "https://dl.fbaipublicfiles.com/laser/WikiMatrix/v1/WikiMatrix.%s-%s.tsv.gz"
    mapping = dict(sh='hbs')
    skips = {'nds_nl', 'simple'}
    for pair in data.split():
        l1, l2 = pair.split('-')
        if l1 in skips or l2 in skips:
            continue
        l1iso, l2iso = mapping.get(l1, l1), mapping.get(l2, l2)
        url = url_pat % (l1, l2)
        ent = Entry(langs=(l1iso, l2iso), url=url, name='WikiMatrix_v1', cols=(1, 2), cite=cite)
        index.add_entry(ent)



#!/usr/bin/env python
#
# Author: Thamme Gowda [tg (at) isi (dot) edu] 
# Created: 5/8/20
# Using English name only; sorry, French!
data="""aar|aa|Afar
abk|ab|Abkhazian
ace||Achinese
ach||Acoli
ada||Adangme
ady||Adyghe; Adygei
afa||Afro-Asiatic languages
afh||Afrihili
afr|af|Afrikaans
ain||Ainu
aka|ak|Akan
akk||Akkadian
alb|sq|Albanian
ale||Aleut
alg||Algonquian languages
alt||Southern Altai
amh|am|Amharic
ang||English, Old (ca.450-1100)
anp||Angika
apa||Apache languages
ara|ar|Arabic
arc||Official Aramaic (700-300 BCE); Imperial Aramaic (700-300 BCE)
arg|an|Aragonese
arm|hy|Armenian
arn||Mapudungun; Mapuche
arp||Arapaho
art||Artificial languages
arw||Arawak
asm|as|Assamese
ast||Asturian; Bable; Leonese; Asturleonese
ath||Athapascan languages
aus||Australian languages
ava|av|Avaric
ave|ae|Avestan
awa||Awadhi
aym|ay|Aymara
aze|az|Azerbaijani
bad||Banda languages
bai||Bamileke languages
bak|ba|Bashkir
bal||Baluchi
bam|bm|Bambara
ban||Balinese
baq|eu|Basque
bas||Basa
bat||Baltic languages
bej||Beja; Bedawiyet
bel|be|Belarusian
bem||Bemba
ben|bn|Bengali
ber||Berber languages
bho||Bhojpuri
bih|bh|Bihari languages
bik||Bikol
bin||Bini; Edo
bis|bi|Bislama
bla||Siksika
bnt||Bantu languages
bos|bs|Bosnian
bra||Braj
bre|br|Breton
btk||Batak languages
bua||Buriat
bug||Buginese
bul|bg|Bulgarian
bur|my|Burmese
byn||Blin; Bilin
cad||Caddo
cai||Central American Indian languages
car||Galibi Carib
cat|ca|Catalan; Valencian
cau||Caucasian languages
ceb||Cebuano
cel||Celtic languages
cha|ch|Chamorro
chb||Chibcha
che|ce|Chechen
chg||Chagatai
chi|zh|Chinese
chk||Chuukese
chm||Mari
chn||Chinook jargon
cho||Choctaw
chp||Chipewyan; Dene Suline
chr||Cherokee
chu|cu|Church Slavic; Old Slavonic; Church Slavonic; Old Bulgarian; Old Church Slavonic
chv|cv|Chuvash
chy||Cheyenne
cmc||Chamic languages
cnr||Montenegrin
cop||Coptic
cor|kw|Cornish
cos|co|Corsican
cpe||Creoles and pidgins, English based
cpf||Creoles and pidgins, French-based
cpp||Creoles and pidgins, Portuguese-based
cre|cr|Cree
crh||Crimean Tatar; Crimean Turkish
crp||Creoles and pidgins
csb||Kashubian
cus||Cushitic languages
cze|cs|Czech
dak||Dakota
dan|da|Danish
dar||Dargwa
day||Land Dayak languages
del||Delaware
den||Slave (Athapascan)
dgr||Dogrib
din||Dinka
div|dv|Divehi; Dhivehi; Maldivian
doi||Dogri
dra||Dravidian languages
dsb||Lower Sorbian
dua||Duala
dum||Dutch, Middle (ca.1050-1350)
dut|nl|Dutch; Flemish
dyu||Dyula
dzo|dz|Dzongkha
efi||Efik
egy||Egyptian (Ancient)
eka||Ekajuk
elx||Elamite
eng|en|English
enm||English, Middle (1100-1500)
epo|eo|Esperanto
est|et|Estonian
ewe|ee|Ewe
ewo||Ewondo
fan||Fang
fao|fo|Faroese
fat||Fanti
fij|fj|Fijian
fil||Filipino; Pilipino
fin|fi|Finnish
fiu||Finno-Ugrian languages
fon||Fon
fre|fr|French
frm||French, Middle (ca.1400-1600)
fro||French, Old (842-ca.1400)
frr||Northern Frisian
frs||Eastern Frisian
fry|fy|Western Frisian
ful|ff|Fulah
fur||Friulian
gaa||Ga
gay||Gayo
gba||Gbaya
gem||Germanic languages
geo|ka|Georgian
ger|de|German
gez||Geez
gil||Gilbertese
gla|gd|Gaelic; Scottish Gaelic
gle|ga|Irish
glg|gl|Galician
glv|gv|Manx
gmh||German, Middle High (ca.1050-1500)
goh||German, Old High (ca.750-1050)
gon||Gondi
gor||Gorontalo
got||Gothic
grb||Grebo
grc||Ancient Greek (-1453)
gre|el|Modern Greek (1453-)
grn|gn|Guarani
gsw||Swiss German; Alemannic; Alsatian
guj|gu|Gujarati
gwi||Gwich'in
hai||Haida
hat|ht|Haitian; Haitian Creole
hau|ha|Hausa
haw||Hawaiian
heb|he|Hebrew
her|hz|Herero
hil||Hiligaynon
him||Himachali languages; Western Pahari languages
hin|hi|Hindi
hit||Hittite
hmn||Hmong; Mong
hmo|ho|Hiri Motu
hrv|hr|Croatian
hsb||Upper Sorbian
hun|hu|Hungarian
hup||Hupa
iba||Iban
ibo|ig|Igbo
ice|is|Icelandic
ido|io|Ido
iii|ii|Sichuan Yi; Nuosu
ijo||Ijo languages
iku|iu|Inuktitut
ile|ie|Interlingue; Occidental
ilo||Iloko
ina|ia|Interlingua (International Auxiliary Language Association)
inc||Indic languages
ind|id|Indonesian
ine||Indo-European languages
inh||Ingush
ipk|ik|Inupiaq
ira||Iranian languages
iro||Iroquoian languages
ita|it|Italian
jav|jv|Javanese
jbo||Lojban
jpn|ja|Japanese
jpr||Judeo-Persian
jrb||Judeo-Arabic
kaa||Kara-Kalpak
kab||Kabyle
kac||Kachin; Jingpho
kal|kl|Kalaallisut; Greenlandic
kam||Kamba
kan|kn|Kannada
kar||Karen languages
kas|ks|Kashmiri
kau|kr|Kanuri
kaw||Kawi
kaz|kk|Kazakh
kbd||Kabardian
kha||Khasi
khi||Khoisan languages
khm|km|Central Khmer
kho||Khotanese; Sakan
kik|ki|Kikuyu; Gikuyu
kin|rw|Kinyarwanda
kir|ky|Kirghiz; Kyrgyz
kmb||Kimbundu
kok||Konkani
kom|kv|Komi
kon|kg|Kongo
kor|ko|Korean
kos||Kosraean
kpe||Kpelle
krc||Karachay-Balkar
krl||Karelian
kro||Kru languages
kru||Kurukh
kua|kj|Kuanyama; Kwanyama
kum||Kumyk
kur|ku|Kurdish
kut||Kutenai
lad||Ladino
lah||Lahnda
lam||Lamba
lao|lo|Lao
lat|la|Latin
lav|lv|Latvian
lez||Lezghian
lim|li|Limburgan; Limburger; Limburgish
lin|ln|Lingala
lit|lt|Lithuanian
lol||Mongo
loz||Lozi
ltz|lb|Luxembourgish; Letzeburgesch
lua||Luba-Lulua
lub|lu|Luba-Katanga
lug|lg|Ganda
lui||Luiseno
lun||Lunda
luo||Luo (Kenya and Tanzania)
lus||Lushai
mac|mk|Macedonian
mad||Madurese
mag||Magahi
mah|mh|Marshallese
mai||Maithili
mak||Makasar
mal|ml|Malayalam
man||Mandingo
mao|mi|Maori
map||Austronesian languages
mar|mr|Marathi
mas||Masai
may|ms|Malay
mdf||Moksha
mdr||Mandar
men||Mende
mga||Irish, Middle (900-1200)
mic||Mi'kmaq; Micmac
min||Minangkabau
mis||Uncoded languages
mkh||Mon-Khmer languages
mlg|mg|Malagasy
mlt|mt|Maltese
mnc||Manchu
mni||Manipuri
mno||Manobo languages
moh||Mohawk
mon|mn|Mongolian
mos||Mossi
mul||Multiple languages
mun||Munda languages
mus||Creek
mwl||Mirandese
mwr||Marwari
myn||Mayan languages
myv||Erzya
nah||Nahuatl languages
nai||North American Indian languages
nap||Neapolitan
nau|na|Nauru
nav|nv|Navajo; Navaho
nbl|nr|Ndebele, South; South Ndebele
nde|nd|Ndebele, North; North Ndebele
ndo|ng|Ndonga
nds||Low German; Low Saxon; German, Low; Saxon, Low
nep|ne|Nepali
new||Nepal Bhasa; Newari
nia||Nias
nic||Niger-Kordofanian languages
niu||Niuean
nno|nn|Norwegian Nynorsk; Nynorsk, Norwegian
nob|nb|Bokmål, Norwegian; Norwegian Bokmål
nog||Nogai
non||Norse, Old
nor|no|Norwegian
nqo||N'Ko
nso||Pedi; Sepedi; Northern Sotho
nub||Nubian languages
nwc||Classical Newari; Old Newari; Classical Nepal Bhasa
nya|ny|Chichewa; Chewa; Nyanja
nym||Nyamwezi
nyn||Nyankole
nyo||Nyoro
nzi||Nzima
oci|oc|Occitan (post 1500)
oji|oj|Ojibwa
ori|or|Oriya
orm|om|Oromo
osa||Osage
oss|os|Ossetian; Ossetic
ota||Turkish, Ottoman (1500-1928)
oto||Otomian languages
paa||Papuan languages
pag||Pangasinan
pal||Pahlavi
pam||Pampanga; Kapampangan
pan|pa|Panjabi; Punjabi
pap||Papiamento
pau||Palauan
peo||Persian, Old (ca.600-400 B.C.)
per|fa|Persian
phi||Philippine languages
phn||Phoenician
pli|pi|Pali
pol|pl|Polish
pon||Pohnpeian
por|pt|Portuguese
pra||Prakrit languages
pro||Provençal, Old (to 1500); Occitan, Old (to 1500)
pus|ps|Pushto; Pashto
qaa-qtz||Reserved for local use
que|qu|Quechua
raj||Rajasthani
rap||Rapanui
rar||Rarotongan; Cook Islands Maori
roa||Romance languages
roh|rm|Romansh
rom||Romany
rum|ro|Romanian; Moldavian; Moldovan
run|rn|Rundi
rup||Aromanian; Arumanian; Macedo-Romanian
rus|ru|Russian
sad||Sandawe
sag|sg|Sango
sah||Yakut
sai||South American Indian languages
sal||Salishan languages
sam||Samaritan Aramaic
san|sa|Sanskrit
sas||Sasak
sat||Santali
scn||Sicilian
sco||Scots
sel||Selkup
sem||Semitic languages
sga||Irish, Old (to 900)
sgn||Sign Languages
shn||Shan
sid||Sidamo
sin|si|Sinhala; Sinhalese
sio||Siouan languages
sit||Sino-Tibetan languages
sla||Slavic languages
slo|sk|Slovak
slv|sl|Slovenian
sma||Southern Sami
sme|se|Northern Sami
smi||Sami languages
smj||Lule Sami
smn||Inari Sami
smo|sm|Samoan
sms||Skolt Sami
sna|sn|Shona
snd|sd|Sindhi
snk||Soninke
sog||Sogdian
som|so|Somali
son||Songhai languages
sot|st|Sotho, Southern
spa|es|Spanish; Castilian
srd|sc|Sardinian
srn||Sranan Tongo
srp|sr|Serbian
srr||Serer
ssa||Nilo-Saharan languages
ssw|ss|Swati
suk||Sukuma
sun|su|Sundanese
sus||Susu
sux||Sumerian
swa|sw|Swahili
swe|sv|Swedish
syc||Classical Syriac
syr||Syriac
tah|ty|Tahitian
tai||Tai languages
tam|ta|Tamil
tat|tt|Tatar
tel|te|Telugu
tem||Timne
ter||Tereno
tet||Tetum
tgk|tg|Tajik
tgl|tl|Tagalog
tha|th|Thai
tib|bo|Tibetan
tig||Tigre
tir|ti|Tigrinya
tiv||Tiv
tkl||Tokelau
tlh||Klingon; tlhIngan-Hol
tli||Tlingit
tmh||Tamashek
tog||Tonga (Nyasa)
ton|to|Tonga (Tonga Islands)
tpi||Tok Pisin
tsi||Tsimshian
tsn|tn|Tswana
tso|ts|Tsonga
tuk|tk|Turkmen
tum||Tumbuka
tup||Tupi languages
tur|tr|Turkish
tut||Altaic languages
tvl||Tuvalu
twi|tw|Twi
tyv||Tuvinian
udm||Udmurt
uga||Ugaritic
uig|ug|Uighur; Uyghur
ukr|uk|Ukrainian
umb||Umbundu
und||Undetermined
urd|ur|Urdu
uzb|uz|Uzbek
vai||Vai
ven|ve|Venda
vie|vi|Vietnamese
vol|vo|Volapük
vot||Votic
wak||Wakashan languages
wal||Wolaitta; Wolaytta
war||Waray
was||Washo
wel|cy|Welsh
wen||Sorbian languages
wln|wa|Walloon
wol|wo|Wolof
xal||Kalmyk; Oirat
xho|xh|Xhosa
yao||Yao
yap||Yapese
yid|yi|Yiddish
yor|yo|Yoruba
ypk||Yupik languages
zap||Zapotec
zbl||Blissymbols; Blissymbolics; Bliss
zen||Zenaga
zgh||Standard Moroccan Tamazight
zha|za|Zhuang; Chuang
znd||Zande languages
zul|zu|Zulu
zun||Zuni
zxx||No linguistic content; Not applicable
zza||Zaza; Dimili; Dimli; Kirdki; Kirmanjki; Zazaki"""

CODES3 = {}
CODE2_TO_3 = {}

for line in data.splitlines():
    code3, code2, names = line.split("|")
    code2 = code2 or None
    names = names.split(";")
    CODES3[code3] = (names[0], code2, names[1:])
    if code2:
        CODE2_TO_3[code2] = code3

def code2_to_code3_name(code):
    assert len(code) == 2
    code3 = CODE2_TO_3.get(code, None)
    name = CODES3[code3][0] if code3 else None
    return code3, name



#!/usr/bin/env python
#
# Author: Thamme Gowda [tg (at) isi (dot) edu]
# Created: 4/7/20

import scrapy

from mtdatabot.items import MTDataItem, MTCorpusItem

class OpusSpider(scrapy.Spider):
    name = 'opus'
    start_urls = ['http://opus.nlpl.eu/']


    def parse(self, response):
        dataset_pages = response.xpath('(//td[2])[1]//a/@href').getall()
        for url in dataset_pages:
            yield response.follow(url, callback=self.parse_dataset_listing)

    def parse_dataset_listing(self, response):
        self.logger.info(f"Parsing dataset listing : {response.url}")
        suffix = '.txt.zip'
        if response.url.endswith('JW300.php'):  # this one doesnt have moses txt
            suffix = '.xml.gz'

        # URL of form "<prefix>?download?f=dataset/version/moses/src-tgt.zip"
        if getattr(self, 'flat', None):
            # flat all datasets into individual items
            anchors = response.xpath(f"//a[contains(@href, '{suffix}')]")
            self.logger.info(f"Found {len(anchors)} pairs")
            for anch in anchors:
                url = response.urljoin(anch.xpath('./@href').get())
                file_path = url.split('?f=')[-1]
                parts = [p for p in file_path.split('/') if p != 'moses']
                name = '_'.join(parts[:-1]).replace('-', '_')
                lang_pair = parts[-1].replace(suffix, '').split('-')
                if len(lang_pair) != 2:
                    self.logger.warning(f"Couldnt parse {url} properly; skipped")
                    continue

                item = MTDataItem()
                item['url'] = url
                item['name'] = name
                item['id'] = file_path
                item['langs'] = lang_pair
                item['title'] = anch.xpath('./@title').get().strip().replace(' - Moses format', '')
                item['info'] = anch.xpath('./text()').get().strip()
                yield item
        else: # Just one entry -- takes less space on disk
            urls = response.xpath(f"//a[contains(@href, '{suffix}')]/@href").getall()
            # extract corpus info from first URL, and generalize URL pattern
            if not urls:
                self.logger.warning(f"Found 0 URLS in {response.url}")
            else:
                self.logger.info(f"Found {len(urls)} pairs")
                url = urls[0]
                full_url = response.urljoin('/'.join(url.split('/')[:-1]) + f'/%s-%s{suffix}')
                corp_name = '_'.join(url.split('?f=')[-1].split('/')[:-2]).replace('-', '_')
                langs = []
                for url in urls:
                    lang_pair = url.split('/')[-1].replace(suffix, '').split('-')
                    if len(lang_pair) != 2:
                        self.logger.warning(f"Could not parse {url} properly; skipped")
                        continue
                    langs.append(lang_pair)

                item = MTCorpusItem()
                item['url'] = full_url
                item['name'] = corp_name
                item['langs'] = langs
                yield item


#!/usr/bin/env python
#
# Author: Thamme Gowda [tg (at) isi (dot) edu] 
# Created: 4/8/20
from mtdata import log
from mtdata.entry import Entry, Paper


class Index:

    def __init__(self):
        self.entries = {}  # uniq
        self.papers = {}  # uniq

    @property
    def n_entries(self) -> int:
        return len(self.entries)

    def add_entry(self, entry: Entry):
        assert isinstance(entry, Entry)
        key = (entry.name, entry.langs)
        assert key not in self.entries, f'{key} is a duplicate'
        self.entries[key] = entry

    def add_paper(self, paper: Paper):
        assert isinstance(paper, Paper)
        assert paper.name not in self.papers, f'{paper.name} is a duplicate'
        self.papers[paper.name] = paper

    def get_entries(self):
        return self.entries.values()

    def get_papers(self):
        return self.papers.values()

    def contains_entry(self, name, langs):
        key = (name, langs)
        return key in self.entries

    def contains_paper(self, name):
        return name in self.papers

    def get_entry(self, name, langs):
        assert isinstance(name, str)
        assert isinstance(langs, tuple)
        key = (name, langs)
        rev_key = (name, tuple(reversed(langs)))
        if key not in self.entries and rev_key in self.entries:
            key = rev_key
        return self.entries[key]

    def get_paper(self, name):
        return self.papers[name]

    def __len__(self):
        return len(self.entries)


INDEX: Index = Index()


def get_entries(langs=None, names=None, not_names=None):
    """
    :param langs: language pairs  to select eg ('en', 'de')
    :param names:  names to select
    :param not_names:  names to exclude
    :return: list of dataset entries that match the criteria
    """
    select = list(INDEX.get_entries())
    if names:
        if not isinstance(names, set):
            names = set(names)
        select = [e for e in select if e.name in names]
    if langs:
        assert len(langs) == 2
        langs = sorted(langs)
        select = [e for e in select if langs == sorted(e.langs)]
    if not_names:
        if not isinstance(not_names, set):
            not_names = set(not_names)
        select = [e for e in select if e.name not in not_names]
    return select


def load_all():
    from mtdata.index import (statmt, paracrawl, tilde, literature, joshua_indian, globalvoices,
                              unitednations, wikimatrix, other, neulab_tedtalks)
    from mtdata.index.opus import opus_index, jw300, opus100

    counts = {}
    subsets = [
        ('Statmt.org', statmt.load),
        ('Paracrawl', paracrawl.load),
        ('Tilde', tilde.load),
        ('JoshuaIndianCoprus', joshua_indian.load_all),
        ('GlobalVoices', globalvoices.load_all),
        ('UnitedNations', unitednations.load_all),
        ('OPUS', opus_index.load_all),
        ('OPUS_JW300', jw300.load_all),
        ('OPUS100', opus100.load_all),
        ('WikiMatrix', wikimatrix.load_all),
        ('Other', other.load_all),
        ('Neulab_TEDTalksv1', neulab_tedtalks.load_all),
    ]
    for name, loader in subsets:
        n = len(INDEX)
        loader(INDEX)
        counts[name] = len(INDEX) - n
    counts['Total'] = len(INDEX)

    counts = '  '.join([f'{n}:{c:,}' for n, c in counts.items()])
    log.info(f"Loaded entries: {counts}")
    literature.load(INDEX)


# eager load, as of now TODO: lazy load
load_all()



#!/usr/bin/env python
#
# Author: Thamme Gowda [tg (at) isi (dot) edu] 
# Created: 5/12/20

# You shouldnt be using ISO 639 1 anymore. The only use of this list is to map the 2 letter code to
# 3 letter code of ISO 639 3
# this list is obtained from https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes
data = """ab,abk
aa,aar
af,afr
ak,aka
sq,sqi
am,amh
ar,ara
an,arg
hy,hye
as,asm
av,ava
ae,ave
ay,aym
az,aze
bm,bam
ba,bak
eu,eus
be,bel
bn,ben
bi,bis
bs,bos
br,bre
bg,bul
my,mya
ca,cat
ch,cha
ce,che
ny,nya
zh,zho
cv,chv
kw,cor
co,cos
cr,cre
hr,hrv
cs,ces
da,dan
dv,div
nl,nld
dz,dzo
en,eng
eo,epo
et,est
ee,ewe
fo,fao
fj,fij
fi,fin
fr,fra
ff,ful
gl,glg
ka,kat
de,deu
el,ell
gn,grn
gu,guj
ht,hat
ha,hau
he,heb
hz,her
hi,hin
ho,hmo
hu,hun
ia,ina
id,ind
ie,ile
ga,gle
ig,ibo
ik,ipk
io,ido
is,isl
it,ita
iu,iku
ja,jpn
jv,jav
kl,kal
kn,kan
kr,kau
ks,kas
kk,kaz
km,khm
ki,kik
rw,kin
ky,kir
kv,kom
kg,kon
ko,kor
ku,kur
kj,kua
la,lat
lb,ltz
lg,lug
li,lim
ln,lin
lo,lao
lt,lit
lu,lub
lv,lav
gv,glv
mk,mkd
mg,mlg
ms,msa
ml,mal
mt,mlt
mi,mri
mr,mar
mh,mah
mn,mon
na,nau
nv,nav
nd,nde
ne,nep
ng,ndo
nb,nob
nn,nno
no,nor
ii,iii
nr,nbl
oc,oci
oj,oji
cu,chu
om,orm
or,ori
os,oss
pa,pan
pi,pli
fa,fas
pl,pol
ps,pus
pt,por
qu,que
rm,roh
rn,run
ro,ron
ru,rus
sa,san
sc,srd
sd,snd
se,sme
sm,smo
sg,sag
sr,srp
gd,gla
sn,sna
si,sin
sk,slk
sl,slv
so,som
st,sot
es,spa
su,sun
sw,swa
ss,ssw
sv,swe
ta,tam
te,tel
tg,tgk
th,tha
ti,tir
bo,bod
tk,tuk
tl,tgl
tn,tsn
to,ton
tr,tur
ts,tso
tt,tat
tw,twi
ty,tah
ug,uig
uk,ukr
ur,urd
uz,uzb
ve,ven
vi,vie
vo,vol
wa,wln
cy,cym
wo,wol
fy,fry
xh,xho
yi,yid
yo,yor
za,zha
zu,zul"""

ISO693_1_to_3 = {rec[0]: rec[1] for l in data.splitlines() for rec in [l.strip().split()]}



#!/usr/bin/env python
#
# Author: Thamme Gowda [tg (at) isi (dot) edu] 
# Created: 4/10/20

from typing import Mapping, List
from pathlib import Path
from collections import defaultdict
import json
from pprint import pprint

def read_codes(codes:Path) -> Mapping[str, str]:
    with codes.open('r', encoding='utf8', errors='ignore') as f:
        recs = [line.rstrip('\n').split('\t') for line in f]
        recs = recs[1:] # skip header
        return {r[0].strip(): r[6].strip() for r in recs} # Id, Ref_Name

def read_names(names_index:Path) -> Mapping[str, List[str]]:
    names = defaultdict(list)
    with names_index.open('r', encoding='utf8', errors='ignore') as f:
        recs = [line.rstrip('\n').split('\t') for line in f]
        recs = recs[1:] # skip header
        for r in recs:
            names[r[0]].append(r[1])
        return dict(names)

def parse(codes: Path, names_index: Path):
    codes = read_codes(codes)
    names = read_names(names_index)
    assert set(codes.keys()) == set(names.keys())
    res = {}
    for code, ref_name in codes.items():
        more_names = list(set(names[code]) - {ref_name})
        val = [ref_name, more_names]
        res[code] = val
    return res

def myprint(data):
    res = ''
    for code, (ref_name, aliases) in data.items():
        assert not any(',' in a for a in aliases)
        assert not ',' in ref_name
        aliases = ','.join(aliases)
        res += f'{code}\t{ref_name}\t{aliases}\n'
    return res

if __name__ == '__main__':
    codes = Path('iso-639-3.tsv')
    names = Path('iso-639-3-names.tsv')
    res = parse(codes, names)
    res = myprint(res).rstrip('\n')

    out = f"""
# ISO 639-3 codes  retrieved from https://iso639-3.sil.org/code_tables/download_tables
#
# Prepared as python module by Thamme Gowda for mtdata https://github.com/thammegowda/mtdata

data='''{res}'''

codes = dict() 
for line in data.splitlines():
    code, ref_name, aliases = line.split('\\t')
    aliases = set(aliases.split('.')) if aliases else set()
    codes[code] = (ref_name, aliases)
"""
    print(out)

